AccelerationStructureGeometryData

Enum AccelerationStructureGeometryData 

pub enum AccelerationStructureGeometryData {
    AABBs {
        addr: DeviceOrHostAddress,
        stride: DeviceSize,
    },
    Instances {
        addr: DeviceOrHostAddress,
        array_of_pointers: bool,
    },
    Triangles {
        index_addr: DeviceOrHostAddress,
        index_type: IndexType,
        max_vertex: u32,
        transform_addr: Option<DeviceOrHostAddress>,
        vertex_addr: DeviceOrHostAddress,
        vertex_format: Format,
        vertex_stride: DeviceSize,
    },
}
Specifies acceleration structure geometry data.

See VkAccelerationStructureGeometryDataKHR for more information.

Variants



AABBs

Axis-aligned bounding box geometry in a bottom-level acceleration structure.

See VkAccelerationStructureGeometryAabbsDataKHR for more information.

Fields

addr: DeviceOrHostAddress

A device or host address to memory containing vk::AabbPositionsKHR structures containing position data for each axis-aligned bounding box in the geometry.

stride: DeviceSize

Stride in bytes between each entry in data.

The stride must be a multiple of 8.



Instances

Geometry consisting of instances of other acceleration structures.

See VkAccelerationStructureGeometryInstancesDataKHR for more information.

Fields

addr: DeviceOrHostAddress

Either the address of an array of device referencing individual VkAccelerationStructureInstanceKHR structures or packed motion instance information as described in motion instances if array_of_pointers is true, or the address of an array of VkAccelerationStructureInstanceKHR structures.

Addresses and VkAccelerationStructureInstanceKHR structures are tightly packed.

array_of_pointers: bool

Specifies whether data is used as an array of addresses or just an array.



Triangles

A triangle geometry in a bottom-level acceleration structure.

See VkAccelerationStructureGeometryTrianglesDataKHR for more information.

Fields

index_addr: DeviceOrHostAddress

A device or host address to memory containing index data for this geometry.

index_type: IndexType

The VkIndexType of each index element.

max_vertex: u32

The highest index of a vertex that will be addressed by a build command using this structure.

transform_addr: Option<DeviceOrHostAddress>

A device or host address to memory containing an optional reference to a VkTransformMatrixKHR structure describing a transformation from the space in which the vertices in this geometry are described to the space in which the acceleration structure is defined.

vertex_addr: DeviceOrHostAddress

A device or host address to memory containing vertex data for this geometry.

vertex_format: Format

The VkFormat of each vertex element.

vertex_stride: DeviceSize

The stride in bytes between each vertex.

Implementations

Source

impl AccelerationStructureGeometryData

pub fn aabbs(addr: impl Into<DeviceOrHostAddress>, stride: DeviceSize) -> Self

Specifies acceleration structure geometry data as AABBs.

pub fn instances(addr: impl Into<DeviceOrHostAddress>) -> Self

Specifies acceleration structure geometry data as instances.

pub fn instance_pointers(addr: impl Into<DeviceOrHostAddress>) -> Self

Specifies acceleration structure geometry data as an array of instance pointers.

pub fn triangles( index_addr: impl Into<DeviceOrHostAddress>, index_type: IndexType, max_vertex: u32, transform_addr: impl Into<Option<DeviceOrHostAddress>>, vertex_addr: impl Into<DeviceOrHostAddress>, vertex_format: Format, vertex_stride: DeviceSize, ) -> Self

Specifies acceleration structure geometry data as triangles.