pub struct BufferInfoBuilder { /* private fields */ }
Builder for BufferInfo.

Implementations

Byte alignment of the base device address of the buffer.

Must be a power of two.

Size in bytes of the buffer to be created.

A bitmask of specifying allowed usages of the buffer.

Specifies a buffer whose memory is host visible and may be mapped.

Builds a new BufferInfo.