pub struct ComputePipeline {
    pub info: ComputePipelineInfo,
    /* private fields */
}
Smart pointer handle to a pipeline object.

Also contains information about the object.

Deref behavior

ComputePipeline automatically dereferences to vk::Pipeline (via the Deref trait), so you can call vk::Pipeline’s methods on a value of type ComputePipeline.

Fields

info: ComputePipelineInfo

Information used to create this object.

Implementations

Creates a new compute pipeline on the given device.

Panics

If shader code is not a multiple of four bytes.

Examples

Basic usage:

// my_shader_code is raw SPIR-V code as bytes
let shader = Shader::new_compute(my_shader_code.as_slice());
let pipeline = ComputePipeline::create(&device, ComputePipelineInfo::default(), shader)?;

assert_ne!(*pipeline, vk::Pipeline::null());