pub enum AccessType {
Show 58 variants Nothing, CommandBufferReadNVX, IndirectBuffer, IndexBuffer, VertexBuffer, VertexShaderReadUniformBuffer, VertexShaderReadSampledImageOrUniformTexelBuffer, VertexShaderReadOther, TessellationControlShaderReadUniformBuffer, TessellationControlShaderReadSampledImageOrUniformTexelBuffer, TessellationControlShaderReadOther, TessellationEvaluationShaderReadUniformBuffer, TessellationEvaluationShaderReadSampledImageOrUniformTexelBuffer, TessellationEvaluationShaderReadOther, GeometryShaderReadUniformBuffer, GeometryShaderReadSampledImageOrUniformTexelBuffer, GeometryShaderReadOther, FragmentShaderReadUniformBuffer, FragmentShaderReadSampledImageOrUniformTexelBuffer, FragmentShaderReadColorInputAttachment, FragmentShaderReadDepthStencilInputAttachment, FragmentShaderReadOther, ColorAttachmentRead, DepthStencilAttachmentRead, ComputeShaderReadUniformBuffer, ComputeShaderReadSampledImageOrUniformTexelBuffer, ComputeShaderReadOther, AnyShaderReadUniformBuffer, AnyShaderReadUniformBufferOrVertexBuffer, AnyShaderReadSampledImageOrUniformTexelBuffer, AnyShaderReadOther, TransferRead, HostRead, Present, CommandBufferWriteNVX, VertexShaderWrite, TessellationControlShaderWrite, TessellationEvaluationShaderWrite, GeometryShaderWrite, FragmentShaderWrite, ColorAttachmentWrite, DepthStencilAttachmentWrite, DepthAttachmentWriteStencilReadOnly, StencilAttachmentWriteDepthReadOnly, ComputeShaderWrite, AnyShaderWrite, TransferWrite, HostWrite, ColorAttachmentReadWrite, General, RayTracingShaderReadSampledImageOrUniformTexelBuffer, RayTracingShaderReadColorInputAttachment, RayTracingShaderReadDepthStencilInputAttachment, RayTracingShaderReadAccelerationStructure, RayTracingShaderReadOther, AccelerationStructureBuildWrite, AccelerationStructureBuildRead, AccelerationStructureBufferWrite,
}
Defines all potential resource usages

Variants



Nothing

No access. Useful primarily for initialization



CommandBufferReadNVX

Command buffer read operation as defined by NVX_device_generated_commands



IndirectBuffer

Read as an indirect buffer for drawing or dispatch



IndexBuffer

Read as an index buffer for drawing



VertexBuffer

Read as a vertex buffer for drawing



VertexShaderReadUniformBuffer

Read as a uniform buffer in a vertex shader



VertexShaderReadSampledImageOrUniformTexelBuffer

Read as a sampled image/uniform texel buffer in a vertex shader



VertexShaderReadOther

Read as any other resource in a vertex shader



TessellationControlShaderReadUniformBuffer

Read as a uniform buffer in a tessellation control shader



TessellationControlShaderReadSampledImageOrUniformTexelBuffer

Read as a sampled image/uniform texel buffer in a tessellation control shader



TessellationControlShaderReadOther

Read as any other resource in a tessellation control shader



TessellationEvaluationShaderReadUniformBuffer

Read as a uniform buffer in a tessellation evaluation shader



TessellationEvaluationShaderReadSampledImageOrUniformTexelBuffer

Read as a sampled image/uniform texel buffer in a tessellation evaluation shader



TessellationEvaluationShaderReadOther

Read as any other resource in a tessellation evaluation shader



GeometryShaderReadUniformBuffer

Read as a uniform buffer in a geometry shader



GeometryShaderReadSampledImageOrUniformTexelBuffer

Read as a sampled image/uniform texel buffer in a geometry shader



GeometryShaderReadOther

Read as any other resource in a geometry shader



FragmentShaderReadUniformBuffer

Read as a uniform buffer in a fragment shader



FragmentShaderReadSampledImageOrUniformTexelBuffer

Read as a sampled image/uniform texel buffer in a fragment shader



FragmentShaderReadColorInputAttachment

Read as an input attachment with a color format in a fragment shader



FragmentShaderReadDepthStencilInputAttachment

Read as an input attachment with a depth/stencil format in a fragment shader



FragmentShaderReadOther

Read as any other resource in a fragment shader



ColorAttachmentRead

Read by blending/logic operations or subpass load operations



DepthStencilAttachmentRead

Read by depth/stencil tests or subpass load operations



ComputeShaderReadUniformBuffer

Read as a uniform buffer in a compute shader



ComputeShaderReadSampledImageOrUniformTexelBuffer

Read as a sampled image/uniform texel buffer in a compute shader



ComputeShaderReadOther

Read as any other resource in a compute shader



AnyShaderReadUniformBuffer

Read as a uniform buffer in any shader



AnyShaderReadUniformBufferOrVertexBuffer

Read as a uniform buffer in any shader, or a vertex buffer



AnyShaderReadSampledImageOrUniformTexelBuffer

Read as a sampled image in any shader



AnyShaderReadOther

Read as any other resource (excluding attachments) in any shader



TransferRead

Read as the source of a transfer operation



HostRead

Read on the host



Present

Read by the presentation engine (i.e. vkQueuePresentKHR)



CommandBufferWriteNVX

Command buffer write operation as defined by NVX_device_generated_commands



VertexShaderWrite

Written as any resource in a vertex shader



TessellationControlShaderWrite

Written as any resource in a tessellation control shader



TessellationEvaluationShaderWrite

Written as any resource in a tessellation evaluation shader



GeometryShaderWrite

Written as any resource in a geometry shader



FragmentShaderWrite

Written as any resource in a fragment shader



ColorAttachmentWrite

Written as a color attachment during rendering, or via a subpass store op



DepthStencilAttachmentWrite

Written as a depth/stencil attachment during rendering, or via a subpass store op



DepthAttachmentWriteStencilReadOnly

Written as a depth aspect of a depth/stencil attachment during rendering, whilst the stencil aspect is read-only. Requires VK_KHR_maintenance2 to be enabled.



StencilAttachmentWriteDepthReadOnly

Written as a stencil aspect of a depth/stencil attachment during rendering, whilst the depth aspect is read-only. Requires VK_KHR_maintenance2 to be enabled.



ComputeShaderWrite

Written as any resource in a compute shader



AnyShaderWrite

Written as any resource in any shader



TransferWrite

Written as the destination of a transfer operation



HostWrite

Written on the host



ColorAttachmentReadWrite

Read or written as a color attachment during rendering



General

Covers any access - useful for debug, generally avoid for performance reasons



RayTracingShaderReadSampledImageOrUniformTexelBuffer

Read as a sampled image/uniform texel buffer in a ray tracing shader



RayTracingShaderReadColorInputAttachment

Read as an input attachment with a color format in a ray tracing shader



RayTracingShaderReadDepthStencilInputAttachment

Read as an input attachment with a depth/stencil format in a ray tracing shader



RayTracingShaderReadAccelerationStructure

Read as an acceleration structure in a ray tracing shader



RayTracingShaderReadOther

Read as any other resource in a ray tracing shader



AccelerationStructureBuildWrite

Written as an acceleration structure during acceleration structure building



AccelerationStructureBuildRead

Read as an acceleration structure during acceleration structure building (e.g. a BLAS when building a TLAS)



AccelerationStructureBufferWrite