pub struct BlendModeBuilder { /* private fields */ }Expand description
Builder for BlendMode.
Implementations
Sourceimpl BlendModeBuilder
impl BlendModeBuilder
Sourcepub fn blend_enable(self, value: bool) -> Self
pub fn blend_enable(self, value: bool) -> Self
Controls whether blending is enabled for the corresponding color attachment.
If blending is not enabled, the source fragment’s color for that attachment is passed through unmodified.
Sourcepub fn src_color_blend_factor(self, value: BlendFactor) -> Self
pub fn src_color_blend_factor(self, value: BlendFactor) -> Self
Selects which blend factor is used to determine the source factors.
Sourcepub fn dst_color_blend_factor(self, value: BlendFactor) -> Self
pub fn dst_color_blend_factor(self, value: BlendFactor) -> Self
Selects which blend factor is used to determine the destination factors.
Sourcepub fn color_blend_op(self, value: BlendOp) -> Self
pub fn color_blend_op(self, value: BlendOp) -> Self
Selects which blend operation is used to calculate the RGB values to write to the color attachment.
Sourcepub fn src_alpha_blend_factor(self, value: BlendFactor) -> Self
pub fn src_alpha_blend_factor(self, value: BlendFactor) -> Self
Selects which blend factor is used to determine the source factor.
Sourcepub fn dst_alpha_blend_factor(self, value: BlendFactor) -> Self
pub fn dst_alpha_blend_factor(self, value: BlendFactor) -> Self
Selects which blend factor is used to determine the destination factor.
Sourcepub fn alpha_blend_op(self, value: BlendOp) -> Self
pub fn alpha_blend_op(self, value: BlendOp) -> Self
Selects which blend operation is used to calculate the alpha values to write to the color attachment.
Sourcepub fn color_write_mask(self, value: ColorComponentFlags) -> Self
pub fn color_write_mask(self, value: ColorComponentFlags) -> Self
A bitmask of specifying which of the R, G, B, and/or A components are enabled for writing, as described for the Color Write Mask.