pub struct DepthStencilMode {
pub back: StencilMode,
pub bounds_test: bool,
pub compare_op: CompareOp,
pub depth_test: bool,
pub depth_write: bool,
pub front: StencilMode,
pub min: OrderedFloat<f32>,
pub max: OrderedFloat<f32>,
pub stencil_test: bool,
}Expand description
Specifies the depth bounds tests, stencil test, and depth test pipeline state.
Fields
back: StencilModeControl parameters of the stencil test.
bounds_test: boolControls whether depth bounds testing is enabled.
compare_op: CompareOpA value specifying the comparison operator to use in the depth comparison step of the depth test.
depth_test: boolControls whether depth testing is enabled.
depth_write: boolControls whether depth writes are enabled when depth_test is true.
Depth writes are always disabled when depth_test is false.
front: StencilModeControl parameters of the stencil test.
min: OrderedFloat<f32>Minimum depth bound used in the depth bounds test.
max: OrderedFloat<f32>Maximum depth bound used in the depth bounds test.
stencil_test: boolControls whether stencil testing is enabled.
Implementations
Sourceimpl DepthStencilMode
impl DepthStencilMode
Sourcepub const DEPTH_READ: Self
pub const DEPTH_READ: Self
A commonly used depth/stencil mode
Sourcepub const DEPTH_WRITE: Self
pub const DEPTH_WRITE: Self
A commonly used depth/stencil mode
Sourcepub fn new() -> DepthStencilModeBuilder
pub fn new() -> DepthStencilModeBuilder
Specifies a default depth/stencil mode which is equal to DepthStencilMode::IGNORE.