pub struct DepthStencilModeBuilder { /* private fields */ }
Builder for DepthStencilMode.

Implementations

Control parameters of the stencil test.

Controls whether depth bounds testing is enabled.

A value specifying the comparison operator to use in the depth comparison step of the depth test.

Controls whether depth testing is enabled.

Controls whether depth writes are enabled when depth_test is true.

Depth writes are always disabled when depth_test is false.

Control parameters of the stencil test.

Minimum depth bound used in the depth bounds test.

Maximum depth bound used in the depth bounds test.

Controls whether stencil testing is enabled.

Builds a new DepthStencilMode.