Struct screen_13::driver::graphic::StencilMode
source · pub struct StencilMode {
pub fail_op: StencilOp,
pub pass_op: StencilOp,
pub depth_fail_op: StencilOp,
pub compare_op: CompareOp,
pub compare_mask: u32,
pub write_mask: u32,
pub reference: u32,
}Expand description
Specifies stencil mode during rasterization.
See stencil test.
Fields
fail_op: StencilOpThe action performed on samples that fail the stencil test.
pass_op: StencilOpThe action performed on samples that pass both the depth and stencil tests.
depth_fail_op: StencilOpThe action performed on samples that pass the stencil test and fail the depth test.
compare_op: CompareOpThe comparison operator used in the stencil test.
compare_mask: u32The bits of the unsigned integer stencil values participating in the stencil test.
write_mask: u32The bits of the unsigned integer stencil values updated by the stencil test in the stencil framebuffer attachment.
reference: u32An unsigned integer stencil reference value that is used in the unsigned stencil comparison.
Implementations
sourceimpl StencilMode
impl StencilMode