ImageViewInfo

Struct ImageViewInfo 

#[non_exhaustive]
pub struct ImageViewInfo { pub array_layer_count: u32, pub aspect_mask: ImageAspectFlags, pub base_array_layer: u32, pub base_mip_level: u32, pub fmt: Format, pub mip_level_count: u32, pub ty: ImageViewType, }
Information used to reinterpret an existing Image instance.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
array_layer_count: u32

The number of layers that will be contained in the view.

The default value is vk::REMAINING_ARRAY_LAYERS.

aspect_mask: ImageAspectFlags

The portion of the image that will be contained in the view.

base_array_layer: u32

The first array layer that will be contained in the view.

base_mip_level: u32

The first mip level that will be contained in the view.

fmt: Format

The format and type of the texel blocks that will be contained in the view.

mip_level_count: u32

The number of mip levels that will be contained in the view.

The default value is vk::REMAINING_MIP_LEVELS.

ty: ImageViewType

The basic dimensionality of the view.

Implementations

Source

impl ImageViewInfo

pub const fn new(fmt: Format, ty: ImageViewType) -> ImageViewInfo

Specifies a default view with the given fmt and ty values.

Note

Automatically sets aspect_mask to a suggested value.

pub fn to_builder(self) -> ImageViewInfoBuilder

Converts a ImageViewInfo into a ImageViewInfoBuilder.

pub fn with_type(self, ty: ImageViewType) -> Self

Takes this instance and returns it with a newly specified ImageViewType.