pub enum RayTraceShaderGroupType {
    General,
    ProceduralHitGroup,
    TrianglesHitGroup,
}
Describes a type of ray tracing shader group, which is a collection of shaders which run in the specified mode.

Variants



General

A shader group with a general shader.



ProceduralHitGroup

A shader group with an intersection shader, and optional closest-hit and any-hit shaders.



TrianglesHitGroup

A shader group with a closest-hit shader and optional any-hit shader.