Struct screen_13::driver::ray_trace::RayTracePipelineInfo
source · pub struct RayTracePipelineInfo {
pub bindless_descriptor_count: u32,
pub max_ray_recursion_depth: u32,
pub name: Option<String>,
}Expand description
Information used to create a RayTracePipeline instance.
Fields
bindless_descriptor_count: u32The number of descriptors to allocate for a given binding when using bindless (unbounded) syntax.
The default is 8192.
Examples
Basic usage (GLSL):
#version 460 core
#extension GL_EXT_nonuniform_qualifier : require
layout(set = 0, binding = 0, rgba8) readonly uniform image2D my_binding[];
void main()
{
// my_binding will have space for 8,192 images by default
}max_ray_recursion_depth: u32The maximum recursion depth of shaders executed by this pipeline.
name: Option<String>A descriptive name used in debugging messages.
Implementations
sourceimpl RayTracePipelineInfo
impl RayTracePipelineInfo
sourcepub fn new() -> RayTracePipelineInfoBuilder
pub fn new() -> RayTracePipelineInfoBuilder
Specifies a ray trace pipeline.