pub struct RayTraceShaderGroup {
    pub any_hit_shader: Option<u32>,
    pub closest_hit_shader: Option<u32>,
    pub general_shader: Option<u32>,
    pub intersection_shader: Option<u32>,
    pub ty: RayTraceShaderGroupType,
}
Describes the set of the shader stages to be included in each shader group in the ray trace pipeline.

See VkRayTracingShaderGroupCreateInfoKHR.

Fields

any_hit_shader: Option<u32>

The optional index of the any-hit shader in the group if the shader group has type of RayTraceShaderGroupType::TrianglesHitGroup or RayTraceShaderGroupType::ProceduralHitGroup.

closest_hit_shader: Option<u32>

The optional index of the closest hit shader in the group if the shader group has type of RayTraceShaderGroupType::TrianglesHitGroup or RayTraceShaderGroupType::ProceduralHitGroup.

general_shader: Option<u32>

The index of the ray generation, miss, or callable shader in the group if the shader group has type of RayTraceShaderGroupType::General.

intersection_shader: Option<u32>

The index of the intersection shader in the group if the shader group has type of RayTraceShaderGroupType::ProceduralHitGroup.

ty: RayTraceShaderGroupType

The type of hit group specified in this structure.

Implementations

Creates a new general-type shader group with the given general shader.

Creates a new procedural-type shader group with the given intersection shader, and optional closest-hit and any-hit shaders.

Creates a new triangles-type shader group with the given closest-hit shader and optional any-hit shader.