Module screen_13::driver::shader

source ·
Shader resource types

Structs

Describes a shader program which runs on some pipeline stage.
Builder for Shader.
Describes specialized constant values.

Traits

Trait for types which can be converted into shader code.