#[repr(transparent)]pub struct RenderingInfoBuilder<'a> { /* private fields */ }Implementations
sourceimpl<'a> RenderingInfoBuilder<'a>
impl<'a> RenderingInfoBuilder<'a>
pub fn flags(self, flags: RenderingFlags) -> RenderingInfoBuilder<'a>
pub fn render_area(self, render_area: Rect2D) -> RenderingInfoBuilder<'a>
pub fn layer_count(self, layer_count: u32) -> RenderingInfoBuilder<'a>
pub fn view_mask(self, view_mask: u32) -> RenderingInfoBuilder<'a>
pub fn color_attachments(
self,
color_attachments: &'a [RenderingAttachmentInfo]
) -> RenderingInfoBuilder<'a>
pub fn depth_attachment(
self,
depth_attachment: &'a RenderingAttachmentInfo
) -> RenderingInfoBuilder<'a>
pub fn stencil_attachment(
self,
stencil_attachment: &'a RenderingAttachmentInfo
) -> RenderingInfoBuilder<'a>
sourcepub fn push_next<T>(self, next: &'a mut T) -> RenderingInfoBuilder<'a> where
T: ExtendsRenderingInfo,
pub fn push_next<T>(self, next: &'a mut T) -> RenderingInfoBuilder<'a> where
T: ExtendsRenderingInfo,
Prepends the given extension struct between the root and the first pointer. This
method only exists on structs that can be passed to a function directly. Only
valid extension structs can be pushed into the chain.
If the chain looks like A -> B -> C, and you call builder.push_next(&mut D), then the
chain will look like A -> D -> B -> C.
sourcepub fn build(self) -> RenderingInfo
pub fn build(self) -> RenderingInfo
Calling build will discard all the lifetime information. Only call this if
necessary! Builders implement Deref targeting their corresponding Vulkan struct,
so references to builders can be passed directly to Vulkan functions.