#[repr(transparent)]pub struct VideoProfileKHRBuilder<'a> { /* private fields */ }Implementations
sourceimpl<'a> VideoProfileKHRBuilder<'a>
impl<'a> VideoProfileKHRBuilder<'a>
pub fn video_codec_operation(
self,
video_codec_operation: VideoCodecOperationFlagsKHR
) -> VideoProfileKHRBuilder<'a>
pub fn chroma_subsampling(
self,
chroma_subsampling: VideoChromaSubsamplingFlagsKHR
) -> VideoProfileKHRBuilder<'a>
pub fn luma_bit_depth(
self,
luma_bit_depth: VideoComponentBitDepthFlagsKHR
) -> VideoProfileKHRBuilder<'a>
pub fn chroma_bit_depth(
self,
chroma_bit_depth: VideoComponentBitDepthFlagsKHR
) -> VideoProfileKHRBuilder<'a>
sourcepub fn push_next<T>(self, next: &'a mut T) -> VideoProfileKHRBuilder<'a> where
T: ExtendsVideoProfileKHR,
pub fn push_next<T>(self, next: &'a mut T) -> VideoProfileKHRBuilder<'a> where
T: ExtendsVideoProfileKHR,
Prepends the given extension struct between the root and the first pointer. This
method only exists on structs that can be passed to a function directly. Only
valid extension structs can be pushed into the chain.
If the chain looks like A -> B -> C, and you call builder.push_next(&mut D), then the
chain will look like A -> D -> B -> C.
sourcepub fn build(self) -> VideoProfileKHR
pub fn build(self) -> VideoProfileKHR
Calling build will discard all the lifetime information. Only call this if
necessary! Builders implement Deref targeting their corresponding Vulkan struct,
so references to builders can be passed directly to Vulkan functions.