Pool which leases by looking for compatibile information before creating new resources.
The information for each lease request is loosely bucketed by compatibility. If no acceptable resources exist for the information provided then a new resource is created and returned.
Details
- Acceleration structures may be larger than requested
- Buffers may be larger than request or have additional usage flags
- Images may have additional usage flags
Structs
A high-efficiency resource allocator.