pub struct EventLoop {
    pub device: Arc<Device>,
    pub window: Window,
    /* private fields */
}
Pumps an operating system event loop in order to handle input and other events while drawing to the screen, continuously.

Fields

device: Arc<Device>

Provides access to the current graphics device.

window: Window

Provides access to the current operating system window.

Implementations

Specifies an event loop.

Current window height, in pixels.

Begins running a windowed event loop, providing frame_fn with a context of the current frame.

Current window width, in pixels.

Current window.