#[repr(C)]pub struct AttachmentDescription2<'a> {
pub s_type: StructureType,
pub p_next: *const c_void,
pub flags: AttachmentDescriptionFlags,
pub format: Format,
pub samples: SampleCountFlags,
pub load_op: AttachmentLoadOp,
pub store_op: AttachmentStoreOp,
pub stencil_load_op: AttachmentLoadOp,
pub stencil_store_op: AttachmentStoreOp,
pub initial_layout: ImageLayout,
pub final_layout: ImageLayout,
pub _marker: PhantomData<&'a ()>,
}Expand description
Fields
s_type: StructureTypep_next: *const c_voidflags: AttachmentDescriptionFlagsformat: Formatsamples: SampleCountFlagsload_op: AttachmentLoadOpstore_op: AttachmentStoreOpstencil_load_op: AttachmentLoadOpstencil_store_op: AttachmentStoreOpinitial_layout: ImageLayoutfinal_layout: ImageLayout_marker: PhantomData<&'a ()>Implementations
Sourceimpl<'a> AttachmentDescription2<'a>
impl<'a> AttachmentDescription2<'a>
pub fn flags( self, flags: AttachmentDescriptionFlags, ) -> AttachmentDescription2<'a>
pub fn format(self, format: Format) -> AttachmentDescription2<'a>
pub fn samples(self, samples: SampleCountFlags) -> AttachmentDescription2<'a>
pub fn load_op(self, load_op: AttachmentLoadOp) -> AttachmentDescription2<'a>
pub fn store_op(self, store_op: AttachmentStoreOp) -> AttachmentDescription2<'a>
pub fn stencil_load_op( self, stencil_load_op: AttachmentLoadOp, ) -> AttachmentDescription2<'a>
pub fn stencil_store_op( self, stencil_store_op: AttachmentStoreOp, ) -> AttachmentDescription2<'a>
pub fn initial_layout( self, initial_layout: ImageLayout, ) -> AttachmentDescription2<'a>
pub fn final_layout( self, final_layout: ImageLayout, ) -> AttachmentDescription2<'a>
Sourcepub fn push_next<T>(self, next: &'a mut T) -> AttachmentDescription2<'a>where
T: ExtendsAttachmentDescription2 + ?Sized,
pub fn push_next<T>(self, next: &'a mut T) -> AttachmentDescription2<'a>where
T: ExtendsAttachmentDescription2 + ?Sized,
Prepends the given extension struct between the root and the first pointer. This
method only exists on structs that can be passed to a function directly. Only
valid extension structs can be pushed into the chain.
If the chain looks like A -> B -> C, and you call x.push_next(&mut D), then the
chain will look like A -> D -> B -> C.