#[repr(C)]pub struct ImageBlit2<'a> {
pub s_type: StructureType,
pub p_next: *const c_void,
pub src_subresource: ImageSubresourceLayers,
pub src_offsets: [Offset3D; 2],
pub dst_subresource: ImageSubresourceLayers,
pub dst_offsets: [Offset3D; 2],
pub _marker: PhantomData<&'a ()>,
}Expand description
Fields
s_type: StructureTypep_next: *const c_voidsrc_subresource: ImageSubresourceLayerssrc_offsets: [Offset3D; 2]dst_subresource: ImageSubresourceLayersdst_offsets: [Offset3D; 2]_marker: PhantomData<&'a ()>Implementations
Sourceimpl<'a> ImageBlit2<'a>
impl<'a> ImageBlit2<'a>
pub fn src_subresource( self, src_subresource: ImageSubresourceLayers, ) -> ImageBlit2<'a>
pub fn src_offsets(self, src_offsets: [Offset3D; 2]) -> ImageBlit2<'a>
pub fn dst_subresource( self, dst_subresource: ImageSubresourceLayers, ) -> ImageBlit2<'a>
pub fn dst_offsets(self, dst_offsets: [Offset3D; 2]) -> ImageBlit2<'a>
Sourcepub fn push_next<T>(self, next: &'a mut T) -> ImageBlit2<'a>where
T: ExtendsImageBlit2 + ?Sized,
pub fn push_next<T>(self, next: &'a mut T) -> ImageBlit2<'a>where
T: ExtendsImageBlit2 + ?Sized,
Prepends the given extension struct between the root and the first pointer. This
method only exists on structs that can be passed to a function directly. Only
valid extension structs can be pushed into the chain.
If the chain looks like A -> B -> C, and you call x.push_next(&mut D), then the
chain will look like A -> D -> B -> C.