Struct screen_13::prelude::vk::PhysicalDeviceFeatures2Builder
source · pub struct PhysicalDeviceFeatures2Builder<'a> { /* private fields */ }Implementations
sourceimpl<'a> PhysicalDeviceFeatures2Builder<'a>
impl<'a> PhysicalDeviceFeatures2Builder<'a>
pub fn features(
self,
features: PhysicalDeviceFeatures
) -> PhysicalDeviceFeatures2Builder<'a>
sourcepub fn push_next<T>(self, next: &'a mut T) -> PhysicalDeviceFeatures2Builder<'a>where
T: ExtendsPhysicalDeviceFeatures2,
pub fn push_next<T>(self, next: &'a mut T) -> PhysicalDeviceFeatures2Builder<'a>where
T: ExtendsPhysicalDeviceFeatures2,
Prepends the given extension struct between the root and the first pointer. This
method only exists on structs that can be passed to a function directly. Only
valid extension structs can be pushed into the chain.
If the chain looks like A -> B -> C, and you call builder.push_next(&mut D), then the
chain will look like A -> D -> B -> C.
sourcepub fn build(self) -> PhysicalDeviceFeatures2
pub fn build(self) -> PhysicalDeviceFeatures2
Calling build will discard all the lifetime information. Only call this if
necessary! Builders implement Deref targeting their corresponding Vulkan struct,
so references to builders can be passed directly to Vulkan functions.