#[repr(C)]pub struct PhysicalDeviceVideoFormatInfoKHR<'a> {
pub s_type: StructureType,
pub p_next: *const c_void,
pub image_usage: ImageUsageFlags,
pub _marker: PhantomData<&'a ()>,
}Expand description
Fields
s_type: StructureTypep_next: *const c_voidimage_usage: ImageUsageFlags_marker: PhantomData<&'a ()>Implementations
Sourceimpl<'a> PhysicalDeviceVideoFormatInfoKHR<'a>
impl<'a> PhysicalDeviceVideoFormatInfoKHR<'a>
pub fn image_usage( self, image_usage: ImageUsageFlags, ) -> PhysicalDeviceVideoFormatInfoKHR<'a>
Sourcepub fn push_next<T>(
self,
next: &'a mut T,
) -> PhysicalDeviceVideoFormatInfoKHR<'a>where
T: ExtendsPhysicalDeviceVideoFormatInfoKHR + ?Sized,
pub fn push_next<T>(
self,
next: &'a mut T,
) -> PhysicalDeviceVideoFormatInfoKHR<'a>where
T: ExtendsPhysicalDeviceVideoFormatInfoKHR + ?Sized,
Prepends the given extension struct between the root and the first pointer. This
method only exists on structs that can be passed to a function directly. Only
valid extension structs can be pushed into the chain.
If the chain looks like A -> B -> C, and you call x.push_next(&mut D), then the
chain will look like A -> D -> B -> C.