pub struct Result(_);Expand description
Implementations
sourceimpl Result
impl Result
pub fn result(self) -> Result<(), Result>
pub fn result_with_success<T>(self, v: T) -> Result<T, Result>
pub unsafe fn assume_init_on_success<T>(
self,
v: MaybeUninit<T>
) -> Result<T, Result>
sourceimpl Result
impl Result
sourcepub const EVENT_RESET: Result = Self(4)
pub const EVENT_RESET: Result = Self(4)
An event is unsignaled
sourcepub const INCOMPLETE: Result = Self(5)
pub const INCOMPLETE: Result = Self(5)
A return array was too small for the result
sourcepub const ERROR_OUT_OF_HOST_MEMORY: Result = Self(-1)
pub const ERROR_OUT_OF_HOST_MEMORY: Result = Self(-1)
A host memory allocation has failed
sourcepub const ERROR_OUT_OF_DEVICE_MEMORY: Result = Self(-2)
pub const ERROR_OUT_OF_DEVICE_MEMORY: Result = Self(-2)
A device memory allocation has failed
sourcepub const ERROR_INITIALIZATION_FAILED: Result = Self(-3)
pub const ERROR_INITIALIZATION_FAILED: Result = Self(-3)
Initialization of an object has failed
sourcepub const ERROR_DEVICE_LOST: Result = Self(-4)
pub const ERROR_DEVICE_LOST: Result = Self(-4)
The logical device has been lost. See <
sourcepub const ERROR_MEMORY_MAP_FAILED: Result = Self(-5)
pub const ERROR_MEMORY_MAP_FAILED: Result = Self(-5)
Mapping of a memory object has failed
sourcepub const ERROR_LAYER_NOT_PRESENT: Result = Self(-6)
pub const ERROR_LAYER_NOT_PRESENT: Result = Self(-6)
Layer specified does not exist
sourcepub const ERROR_EXTENSION_NOT_PRESENT: Result = Self(-7)
pub const ERROR_EXTENSION_NOT_PRESENT: Result = Self(-7)
Extension specified does not exist
sourcepub const ERROR_FEATURE_NOT_PRESENT: Result = Self(-8)
pub const ERROR_FEATURE_NOT_PRESENT: Result = Self(-8)
Requested feature is not available on this device
sourcepub const ERROR_INCOMPATIBLE_DRIVER: Result = Self(-9)
pub const ERROR_INCOMPATIBLE_DRIVER: Result = Self(-9)
Unable to find a Vulkan driver
sourcepub const ERROR_TOO_MANY_OBJECTS: Result = Self(-10)
pub const ERROR_TOO_MANY_OBJECTS: Result = Self(-10)
Too many objects of the type have already been created
sourcepub const ERROR_FORMAT_NOT_SUPPORTED: Result = Self(-11)
pub const ERROR_FORMAT_NOT_SUPPORTED: Result = Self(-11)
Requested format is not supported on this device
sourcepub const ERROR_FRAGMENTED_POOL: Result = Self(-12)
pub const ERROR_FRAGMENTED_POOL: Result = Self(-12)
A requested pool allocation has failed due to fragmentation of the pool’s memory
sourcepub const ERROR_UNKNOWN: Result = Self(-13)
pub const ERROR_UNKNOWN: Result = Self(-13)
An unknown error has occurred, due to an implementation or application bug
sourceimpl Result
impl Result
Generated from ‘VK_KHR_surface’
pub const ERROR_SURFACE_LOST_KHR: Result = Self(-1000000000)
pub const ERROR_NATIVE_WINDOW_IN_USE_KHR: Result = Self(-1000000001)
sourceimpl Result
impl Result
Generated from ‘VK_KHR_swapchain’
pub const SUBOPTIMAL_KHR: Result = Self(1000001003)
pub const ERROR_OUT_OF_DATE_KHR: Result = Self(-1000001004)
sourceimpl Result
impl Result
Generated from ‘VK_KHR_display_swapchain’
pub const ERROR_INCOMPATIBLE_DISPLAY_KHR: Result = Self(-1000003001)
sourceimpl Result
impl Result
Generated from ‘VK_EXT_debug_report’
pub const ERROR_VALIDATION_FAILED_EXT: Result = Self(-1000011001)
sourceimpl Result
impl Result
Generated from ‘VK_NV_glsl_shader’
pub const ERROR_INVALID_SHADER_NV: Result = Self(-1000012000)
sourceimpl Result
impl Result
Generated from ‘VK_KHR_video_queue’
pub const ERROR_IMAGE_USAGE_NOT_SUPPORTED_KHR: Result = Self(-1000023000)
pub const ERROR_VIDEO_PICTURE_LAYOUT_NOT_SUPPORTED_KHR: Result = Self(-1000023001)
pub const ERROR_VIDEO_PROFILE_OPERATION_NOT_SUPPORTED_KHR: Result = Self(-1000023002)
pub const ERROR_VIDEO_PROFILE_FORMAT_NOT_SUPPORTED_KHR: Result = Self(-1000023003)
pub const ERROR_VIDEO_PROFILE_CODEC_NOT_SUPPORTED_KHR: Result = Self(-1000023004)
pub const ERROR_VIDEO_STD_VERSION_NOT_SUPPORTED_KHR: Result = Self(-1000023005)
sourceimpl Result
impl Result
Generated from ‘VK_KHR_maintenance1’
pub const ERROR_OUT_OF_POOL_MEMORY_KHR: Result = Self::ERROR_OUT_OF_POOL_MEMORY
sourceimpl Result
impl Result
Generated from ‘VK_KHR_external_memory’
pub const ERROR_INVALID_EXTERNAL_HANDLE_KHR: Result = Self::ERROR_INVALID_EXTERNAL_HANDLE
sourceimpl Result
impl Result
Generated from ‘VK_EXT_image_drm_format_modifier’
pub const ERROR_INVALID_DRM_FORMAT_MODIFIER_PLANE_LAYOUT_EXT: Result = Self(-1000158000)
sourceimpl Result
impl Result
Generated from ‘VK_EXT_descriptor_indexing’
pub const ERROR_FRAGMENTATION_EXT: Result = Self::ERROR_FRAGMENTATION
sourceimpl Result
impl Result
Generated from ‘VK_EXT_global_priority’
pub const ERROR_NOT_PERMITTED_EXT: Result = Self::ERROR_NOT_PERMITTED_KHR
sourceimpl Result
impl Result
Generated from ‘VK_KHR_global_priority’
pub const ERROR_NOT_PERMITTED_KHR: Result = Self(-1000174001)
sourceimpl Result
impl Result
Generated from ‘VK_EXT_buffer_device_address’
pub const ERROR_INVALID_DEVICE_ADDRESS_EXT: Result = Self::ERROR_INVALID_OPAQUE_CAPTURE_ADDRESS
sourceimpl Result
impl Result
Generated from ‘VK_EXT_full_screen_exclusive’
pub const ERROR_FULL_SCREEN_EXCLUSIVE_MODE_LOST_EXT: Result = Self(-1000255000)
sourceimpl Result
impl Result
Generated from ‘VK_KHR_buffer_device_address’
pub const ERROR_INVALID_OPAQUE_CAPTURE_ADDRESS_KHR: Result = Self::ERROR_INVALID_OPAQUE_CAPTURE_ADDRESS
sourceimpl Result
impl Result
Generated from ‘VK_KHR_deferred_host_operations’
pub const THREAD_IDLE_KHR: Result = Self(1000268000)
pub const THREAD_DONE_KHR: Result = Self(1000268001)
pub const OPERATION_DEFERRED_KHR: Result = Self(1000268002)
pub const OPERATION_NOT_DEFERRED_KHR: Result = Self(1000268003)
sourceimpl Result
impl Result
Generated from ‘VK_EXT_pipeline_creation_cache_control’
pub const PIPELINE_COMPILE_REQUIRED_EXT: Result = Self::PIPELINE_COMPILE_REQUIRED
pub const ERROR_PIPELINE_COMPILE_REQUIRED_EXT: Result = Self::PIPELINE_COMPILE_REQUIRED
sourceimpl Result
impl Result
Generated from ‘VK_EXT_image_compression_control’
pub const ERROR_COMPRESSION_EXHAUSTED_EXT: Result = Self(-1000338000)
sourceimpl Result
impl Result
Generated from ‘VK_VERSION_1_1’
pub const ERROR_OUT_OF_POOL_MEMORY: Result = Self(-1000069000)
pub const ERROR_INVALID_EXTERNAL_HANDLE: Result = Self(-1000072003)
sourceimpl Result
impl Result
Generated from ‘VK_VERSION_1_2’
pub const ERROR_FRAGMENTATION: Result = Self(-1000161000)
pub const ERROR_INVALID_OPAQUE_CAPTURE_ADDRESS: Result = Self(-1000257000)