#[repr(C)]pub struct SetDescriptorBufferOffsetsInfoEXT<'a> {
pub s_type: StructureType,
pub p_next: *const c_void,
pub stage_flags: ShaderStageFlags,
pub layout: PipelineLayout,
pub first_set: u32,
pub set_count: u32,
pub p_buffer_indices: *const u32,
pub p_offsets: *const u64,
pub _marker: PhantomData<&'a ()>,
}Expand description
Fields
s_type: StructureTypep_next: *const c_voidstage_flags: ShaderStageFlagslayout: PipelineLayoutfirst_set: u32set_count: u32p_buffer_indices: *const u32p_offsets: *const u64_marker: PhantomData<&'a ()>Implementations
Sourceimpl<'a> SetDescriptorBufferOffsetsInfoEXT<'a>
impl<'a> SetDescriptorBufferOffsetsInfoEXT<'a>
pub fn stage_flags( self, stage_flags: ShaderStageFlags, ) -> SetDescriptorBufferOffsetsInfoEXT<'a>
pub fn layout( self, layout: PipelineLayout, ) -> SetDescriptorBufferOffsetsInfoEXT<'a>
pub fn first_set(self, first_set: u32) -> SetDescriptorBufferOffsetsInfoEXT<'a>
pub fn buffer_indices( self, buffer_indices: &'a [u32], ) -> SetDescriptorBufferOffsetsInfoEXT<'a>
pub fn offsets( self, offsets: &'a [u64], ) -> SetDescriptorBufferOffsetsInfoEXT<'a>
Sourcepub fn push_next<T>(
self,
next: &'a mut T,
) -> SetDescriptorBufferOffsetsInfoEXT<'a>where
T: ExtendsSetDescriptorBufferOffsetsInfoEXT + ?Sized,
pub fn push_next<T>(
self,
next: &'a mut T,
) -> SetDescriptorBufferOffsetsInfoEXT<'a>where
T: ExtendsSetDescriptorBufferOffsetsInfoEXT + ?Sized,
Prepends the given extension struct between the root and the first pointer. This
method only exists on structs that can be passed to a function directly. Only
valid extension structs can be pushed into the chain.
If the chain looks like A -> B -> C, and you call x.push_next(&mut D), then the
chain will look like A -> D -> B -> C.