#[repr(C)]pub struct ShaderCreateInfoEXT<'a> {Show 15 fields
pub s_type: StructureType,
pub p_next: *const c_void,
pub flags: ShaderCreateFlagsEXT,
pub stage: ShaderStageFlags,
pub next_stage: ShaderStageFlags,
pub code_type: ShaderCodeTypeEXT,
pub code_size: usize,
pub p_code: *const c_void,
pub p_name: *const u8,
pub set_layout_count: u32,
pub p_set_layouts: *const DescriptorSetLayout,
pub push_constant_range_count: u32,
pub p_push_constant_ranges: *const PushConstantRange,
pub p_specialization_info: *const SpecializationInfo<'a>,
pub _marker: PhantomData<&'a ()>,
}Expand description
Fields
s_type: StructureTypep_next: *const c_voidflags: ShaderCreateFlagsEXTstage: ShaderStageFlagsnext_stage: ShaderStageFlagscode_type: ShaderCodeTypeEXTcode_size: usizep_code: *const c_voidp_name: *const u8set_layout_count: u32p_set_layouts: *const DescriptorSetLayoutpush_constant_range_count: u32p_push_constant_ranges: *const PushConstantRangep_specialization_info: *const SpecializationInfo<'a>_marker: PhantomData<&'a ()>Implementations
Sourceimpl<'a> ShaderCreateInfoEXT<'a>
impl<'a> ShaderCreateInfoEXT<'a>
pub fn flags(self, flags: ShaderCreateFlagsEXT) -> ShaderCreateInfoEXT<'a>
pub fn stage(self, stage: ShaderStageFlags) -> ShaderCreateInfoEXT<'a>
pub fn next_stage(self, next_stage: ShaderStageFlags) -> ShaderCreateInfoEXT<'a>
pub fn code_type(self, code_type: ShaderCodeTypeEXT) -> ShaderCreateInfoEXT<'a>
pub fn code(self, code: &'a [u8]) -> ShaderCreateInfoEXT<'a>
pub fn name(self, name: &'a CStr) -> ShaderCreateInfoEXT<'a>
pub unsafe fn name_as_c_str(&self) -> Option<&CStr>
pub fn set_layouts( self, set_layouts: &'a [DescriptorSetLayout], ) -> ShaderCreateInfoEXT<'a>
pub fn push_constant_ranges( self, push_constant_ranges: &'a [PushConstantRange], ) -> ShaderCreateInfoEXT<'a>
pub fn specialization_info( self, specialization_info: &'a SpecializationInfo<'a>, ) -> ShaderCreateInfoEXT<'a>
Sourcepub fn push_next<T>(self, next: &'a mut T) -> ShaderCreateInfoEXT<'a>where
T: ExtendsShaderCreateInfoEXT + ?Sized,
pub fn push_next<T>(self, next: &'a mut T) -> ShaderCreateInfoEXT<'a>where
T: ExtendsShaderCreateInfoEXT + ?Sized,
Prepends the given extension struct between the root and the first pointer. This
method only exists on structs that can be passed to a function directly. Only
valid extension structs can be pushed into the chain.
If the chain looks like A -> B -> C, and you call x.push_next(&mut D), then the
chain will look like A -> D -> B -> C.