#[repr(C)]pub struct VideoSessionCreateInfoKHR<'a> {
pub s_type: StructureType,
pub p_next: *const c_void,
pub queue_family_index: u32,
pub flags: VideoSessionCreateFlagsKHR,
pub p_video_profile: *const VideoProfileInfoKHR<'a>,
pub picture_format: Format,
pub max_coded_extent: Extent2D,
pub reference_picture_format: Format,
pub max_dpb_slots: u32,
pub max_active_reference_pictures: u32,
pub p_std_header_version: *const ExtensionProperties,
pub _marker: PhantomData<&'a ()>,
}Expand description
Fields
s_type: StructureTypep_next: *const c_voidqueue_family_index: u32flags: VideoSessionCreateFlagsKHRp_video_profile: *const VideoProfileInfoKHR<'a>picture_format: Formatmax_coded_extent: Extent2Dreference_picture_format: Formatmax_dpb_slots: u32max_active_reference_pictures: u32p_std_header_version: *const ExtensionProperties_marker: PhantomData<&'a ()>Implementations
Sourceimpl<'a> VideoSessionCreateInfoKHR<'a>
impl<'a> VideoSessionCreateInfoKHR<'a>
pub fn queue_family_index( self, queue_family_index: u32, ) -> VideoSessionCreateInfoKHR<'a>
pub fn flags( self, flags: VideoSessionCreateFlagsKHR, ) -> VideoSessionCreateInfoKHR<'a>
pub fn video_profile( self, video_profile: &'a VideoProfileInfoKHR<'a>, ) -> VideoSessionCreateInfoKHR<'a>
pub fn picture_format( self, picture_format: Format, ) -> VideoSessionCreateInfoKHR<'a>
pub fn max_coded_extent( self, max_coded_extent: Extent2D, ) -> VideoSessionCreateInfoKHR<'a>
pub fn reference_picture_format( self, reference_picture_format: Format, ) -> VideoSessionCreateInfoKHR<'a>
pub fn max_dpb_slots(self, max_dpb_slots: u32) -> VideoSessionCreateInfoKHR<'a>
pub fn max_active_reference_pictures( self, max_active_reference_pictures: u32, ) -> VideoSessionCreateInfoKHR<'a>
pub fn std_header_version( self, std_header_version: &'a ExtensionProperties, ) -> VideoSessionCreateInfoKHR<'a>
Sourcepub fn push_next<T>(self, next: &'a mut T) -> VideoSessionCreateInfoKHR<'a>where
T: ExtendsVideoSessionCreateInfoKHR + ?Sized,
pub fn push_next<T>(self, next: &'a mut T) -> VideoSessionCreateInfoKHR<'a>where
T: ExtendsVideoSessionCreateInfoKHR + ?Sized,
Prepends the given extension struct between the root and the first pointer. This
method only exists on structs that can be passed to a function directly. Only
valid extension structs can be pushed into the chain.
If the chain looks like A -> B -> C, and you call x.push_next(&mut D), then the
chain will look like A -> D -> B -> C.