pub struct BlendModeBuilder { /* private fields */ }
Builder for BlendMode.

Implementations

Controls whether blending is enabled for the corresponding color attachment.

If blending is not enabled, the source fragment’s color for that attachment is passed through unmodified.

Selects which blend factor is used to determine the source factors.

Selects which blend factor is used to determine the destination factors.

Selects which blend operation is used to calculate the RGB values to write to the color attachment.

Selects which blend factor is used to determine the source factor.

Selects which blend factor is used to determine the destination factor.

Selects which blend operation is used to calculate the alpha values to write to the color attachment.

A bitmask of specifying which of the R, G, B, and/or A components are enabled for writing, as described for the Color Write Mask.

Builds a new BlendMode.