Struct screen_13::driver::graphic::DepthStencilModeBuilder
source · pub struct DepthStencilModeBuilder { /* private fields */ }Expand description
Builder for DepthStencilMode.
Implementations
sourceimpl DepthStencilModeBuilder
impl DepthStencilModeBuilder
sourcepub fn back(self, value: StencilMode) -> Self
pub fn back(self, value: StencilMode) -> Self
Control parameters of the stencil test.
sourcepub fn bounds_test(self, value: bool) -> Self
pub fn bounds_test(self, value: bool) -> Self
Controls whether depth bounds testing is enabled.
sourcepub fn compare_op(self, value: CompareOp) -> Self
pub fn compare_op(self, value: CompareOp) -> Self
A value specifying the comparison operator to use in the depth comparison step of the depth test.
sourcepub fn depth_test(self, value: bool) -> Self
pub fn depth_test(self, value: bool) -> Self
Controls whether depth testing is enabled.
sourcepub fn depth_write(self, value: bool) -> Self
pub fn depth_write(self, value: bool) -> Self
Controls whether depth writes are enabled when depth_test is true.
Depth writes are always disabled when depth_test is false.
sourcepub fn front(self, value: StencilMode) -> Self
pub fn front(self, value: StencilMode) -> Self
Control parameters of the stencil test.
sourcepub fn min<VALUE: Into<OrderedFloat<f32>>>(self, value: VALUE) -> Self
pub fn min<VALUE: Into<OrderedFloat<f32>>>(self, value: VALUE) -> Self
Minimum depth bound used in the depth bounds test.
sourcepub fn max<VALUE: Into<OrderedFloat<f32>>>(self, value: VALUE) -> Self
pub fn max<VALUE: Into<OrderedFloat<f32>>>(self, value: VALUE) -> Self
Maximum depth bound used in the depth bounds test.
sourcepub fn stencil_test(self, value: bool) -> Self
pub fn stencil_test(self, value: bool) -> Self
Controls whether stencil testing is enabled.
sourceimpl DepthStencilModeBuilder
impl DepthStencilModeBuilder
sourcepub fn build(self) -> DepthStencilMode
pub fn build(self) -> DepthStencilMode
Builds a new DepthStencilMode.