Things which are used in almost every single Screen 13 program.
Re-exports
pub use super::driver::accel_struct::AccelerationStructure;pub use super::driver::accel_struct::AccelerationStructureGeometry;pub use super::driver::accel_struct::AccelerationStructureGeometryData;pub use super::driver::accel_struct::AccelerationStructureGeometryInfo;pub use super::driver::accel_struct::AccelerationStructureInfo;pub use super::driver::accel_struct::AccelerationStructureInfoBuilder;pub use super::driver::accel_struct::AccelerationStructureSize;pub use super::driver::accel_struct::DeviceOrHostAddress;pub use super::driver::buffer::Buffer;pub use super::driver::buffer::BufferInfo;pub use super::driver::buffer::BufferInfoBuilder;pub use super::driver::buffer::BufferSubresource;pub use super::driver::compute::ComputePipeline;pub use super::driver::compute::ComputePipelineInfo;pub use super::driver::compute::ComputePipelineInfoBuilder;pub use super::driver::graphic::BlendMode;pub use super::driver::graphic::BlendModeBuilder;pub use super::driver::graphic::DepthStencilMode;pub use super::driver::graphic::DepthStencilModeBuilder;pub use super::driver::graphic::GraphicPipeline;pub use super::driver::graphic::GraphicPipelineInfo;pub use super::driver::graphic::GraphicPipelineInfoBuilder;pub use super::driver::graphic::StencilMode;pub use super::driver::image::Image;pub use super::driver::image::ImageInfo;pub use super::driver::image::ImageInfoBuilder;pub use super::driver::image::ImageSubresource;pub use super::driver::image::ImageType;pub use super::driver::image::ImageViewInfo;pub use super::driver::image::ImageViewInfoBuilder;pub use super::driver::image::SampleCount;pub use super::driver::ray_trace::RayTracePipeline;pub use super::driver::ray_trace::RayTracePipelineInfo;pub use super::driver::ray_trace::RayTracePipelineInfoBuilder;pub use super::driver::ray_trace::RayTraceShaderGroup;pub use super::driver::ray_trace::RayTraceShaderGroupType;pub use super::driver::shader::Shader;pub use super::driver::shader::ShaderBuilder;pub use super::driver::shader::ShaderCode;pub use super::driver::shader::SpecializationInfo;pub use super::driver::Driver;pub use super::driver::DriverConfig;pub use super::driver::DriverConfigBuilder;pub use super::driver::DriverError;pub use super::driver::PhysicalDeviceAccelerationStructureProperties;pub use super::driver::PhysicalDeviceDescriptorIndexingFeatures;pub use super::driver::PhysicalDeviceRayTracePipelineProperties;pub use super::driver::ResolveMode;pub use super::graph::node::AccelerationStructureLeaseNode;pub use super::graph::node::AccelerationStructureNode;pub use super::graph::node::AnyAccelerationStructureNode;pub use super::graph::node::AnyBufferNode;pub use super::graph::node::AnyImageNode;pub use super::graph::node::BufferLeaseNode;pub use super::graph::node::BufferNode;pub use super::graph::node::ImageLeaseNode;pub use super::graph::node::ImageNode;pub use super::graph::node::SwapchainImageNode;pub use super::graph::pass_ref::PassRef;pub use super::graph::pass_ref::PipelinePassRef;pub use super::graph::ClearColorValue;pub use super::graph::RenderGraph;pub use super::input::update_input;pub use super::input::update_keyboard;pub use super::input::update_mouse;pub use super::pool::hash::HashPool;pub use super::pool::lazy::LazyPool;pub use super::pool::Lease;pub use super::pool::Pool;Modules
Raw Vulkan bindings and types, generated from
vk.xmlMacros
Logs a message at the debug level.
Logs a message at the error level.
Logs a message at the info level.
Logs a message at the trace level.
Logs a message at the warn level.
Structs
Opaque handle to a device object.
A physical display interface.
Pumps an operating system event loop in order to handle input and other events
while drawing to the screen, continuously.
Builder for
EventLoop.Describes optional features of a device.
A request to render a single frame to the provided render graph.
An icon used for the window titlebar, taskbar, etc.
A container for Window-based keyboard input events.
A basic key input mapping.
A position represented in logical pixels.
A size represented in logical pixels.
Handle to a monitor.
A container for Window-based mouse, tablet and touch input events.
Structure which holds data about the physical hardware selected by the current device.
A position represented in physical pixels.
A size represented in physical pixels.
Describes a fullscreen video mode of a monitor.
Represents a window.
Object that allows building windows.
Identifier of a window. Unique for each window.
Enums
Defines all potential resource usages
An error produced when using
Icon::from_rgba with invalid arguments.The behavior of cursor grabbing.
Describes the appearance of the mouse cursor.
Describes error conditions relating to physical displays.
Describes a generic event.
Fullscreen modes.
Describes a screen mode for display.
Describes a button of a mouse controller.
Platform-specific
Symbolic name for a keyboard key.
Describes an event from a [
Window].Traits
A trait for resources which may be bound to a
RenderGraph.A trait for resources which may be unbound from a
RenderGraph.Functions
Centers the mouse cursor within the window.
Returns a reference to the logger.
Sets the mouse cursor at the specified position within the window.